using System;
using Sce.PlayStation.Core;
using Sce.PlayStation.Core.Graphics;
using Sce.PlayStation.Core.Audio;
using Sce.PlayStation.Core.Input;
using Sce.PlayStation.HighLevel.GameEngine2D;
using Sce.PlayStation.HighLevel.GameEngine2D.Base;
using Sce.PlayStation.HighLevel.UI;

namespace StreetDreams
{
	public class MainMenuScene : Sce.PlayStation.HighLevel.GameEngine2D.Scene
	{
		private Sce.PlayStation.HighLevel.UI.Scene uiScene;
		private Bgm mainMenuSong;
		private BgmPlayer mainMenuSongPlayer;
		private const string backgroundImagePath = "Application/assets/images/MainMenuBackground.png";
		private const string backgroundMusicPath = "Application/assets/audio/menuSong.mp3";
		
		public MainMenuScene ()
		{
			this.Camera.SetViewFromViewport();
			this.addUI();
			Touch.GetData(0).Clear();
			Scheduler.Instance.ScheduleUpdateForTarget(this,0,false);
		}
		
		public override void OnEnter()
		{
			this.setBackgroundMusic();
			this.mainMenuSongPlayer.Loop = true;
			this.mainMenuSongPlayer.Play();
		}
		
		public override void OnExit()
		{
			base.OnExit();
			this.mainMenuSongPlayer.Stop();
			this.mainMenuSongPlayer.Dispose();
			this.mainMenuSong.Dispose();
			this.mainMenuSongPlayer = null;
		}
		
		private void setBackgroundMusic()
		{
			this.mainMenuSong = new Bgm(backgroundMusicPath);
			if(this.mainMenuSongPlayer != null)
			{
				this.mainMenuSongPlayer.Dispose ();
			}
			this.mainMenuSongPlayer = this.mainMenuSong.CreatePlayer();
		}
		
		private void addUI()
		{
			Panel panel = new Panel();
			panel.Width = Director.Instance.GL.Context.GetViewport().Width;
			panel.Height = Director.Instance.GL.Context.GetViewport().Height;
			ImageBox backgroundImageBox = new ImageBox();
			backgroundImageBox.Width = panel.Width;
			backgroundImageBox.Height = panel.Height;
			backgroundImageBox.SetPosition(0.0f,0.0f);
			backgroundImageBox.Image = new ImageAsset(backgroundImagePath, false);
			
			Button playButton = new Button();
			playButton.Name = "Play Game";
			playButton.Text = "Play Game";
			playButton.Width = 300;
			playButton.Height = 50;
			playButton.Alpha = 0.8f;
			playButton.SetPosition(panel.Width/2 - 150, 200.0f);
			playButton.TouchEventReceived += (sender, e) => {
				Director.Instance.ReplaceScene(new MainGameScene());
			};
			
			panel.AddChildLast(backgroundImageBox);
			panel.AddChildLast(playButton);
			
			this.uiScene = new Sce.PlayStation.HighLevel.UI.Scene();
			this.uiScene.RootWidget.AddChildLast(panel);
			UISystem.SetScene(this.uiScene);
		}
		
		public override void Update(float dt)
		{
			base.Update(dt);
			UISystem.Update(Touch.GetData(0));
		}
		
		public override void Draw()
		{
			base.Draw();
			UISystem.Render();
		}
		
		~MainMenuScene()
		{
		}
	}
}

