using System;
using Sce.PlayStation.Core;
using Sce.PlayStation.Core.Graphics;
using Sce.PlayStation.Core.Audio;
using Sce.PlayStation.HighLevel.GameEngine2D;
using Sce.PlayStation.HighLevel.GameEngine2D.Base;
using Sce.PlayStation.Core.Input;

namespace StreetDreams
{
	public class TitleScene : Scene
	{
		private TextureInfo titleImageTextureInfo;
		private Texture2D titleImageTexture;
		private Bgm titleSong;
		private BgmPlayer titleSongPlayer;
		private SpriteUV titleScreenSprite;
		private Boolean goToNextScene;
		private Boolean fadingOut;
				
		private const string titleImagePath = "Application/assets/images/StreetDreamsTitle.png";
		private const string backgroundMusicPath = "Application/assets/audio/titleSong.mp3";
		
		public TitleScene ()
		{
			this.goToNextScene = false;
			this.Camera.SetViewFromViewport();
			this.createTitleScreenSprite();
			this.AddChild(titleScreenSprite);
			this.addTitleScreenActions();
			this.setBackgroundMusic();
			Scheduler.Instance.ScheduleUpdateForTarget(this,0,false);
			Touch.GetData(0).Clear();
		}
		
		public override void OnEnter()
		{
			this.titleSongPlayer.Loop = true;
			this.titleSongPlayer.Play();
		}
		
		public override void OnExit()
		{
			base.OnExit();
			this.titleSongPlayer.Stop();
			this.titleSongPlayer.Dispose();
			this.titleSongPlayer = null;
			this.titleSong.Dispose();
			this.titleSong = null;
		}
		
		public override void Update(float dt)
		{
			base.Update(dt);
			if(goToNextScene == false)
			{
				goToNextScene = wantNextScene();
			}
			else
			{
				this.fadeOutScene();
			}
		}
		
		private void createTitleScreenSprite()
		{
			float pivotCenter = 0.5f;
			this.titleImageTexture = new Texture2D(titleImagePath,false);
			this.titleImageTextureInfo = new TextureInfo(this.titleImageTexture);
			this.titleScreenSprite = new SpriteUV(this.titleImageTextureInfo);
			this.titleScreenSprite.Scale = this.titleImageTextureInfo.TextureSizef;
			this.titleScreenSprite.Pivot = new Vector2(pivotCenter,pivotCenter);
			this.titleScreenSprite.Position = new Vector2(Director.Instance.GL.Context.GetViewport().Width/2,
			                                              Director.Instance.GL.Context.GetViewport().Height/2);	
		}
		
		private void addTitleScreenActions()
		{
			this.setTintAction();
		}
		
		private void setBackgroundMusic()
		{
			this.titleSong = new Bgm(backgroundMusicPath);
			if(this.titleSongPlayer != null)
			{
				this.titleSongPlayer.Dispose ();
			}
				this.titleSongPlayer = this.titleSong.CreatePlayer();
		}
		
		private void setTintAction()
		{
			Vector4 originalColor = this.titleScreenSprite.Color;
			this.titleScreenSprite.Color = new Vector4(0,0,0,0);
			var tintAction = new TintTo(originalColor,10.0f);
			ActionManager.Instance.AddAction (tintAction, this.titleScreenSprite);
			tintAction.Run();
		}
		
		private void setAntiTintAction()
		{
			Vector4 originalColor = this.titleScreenSprite.Color;
			var tintAction = new TintTo(new Vector4(0,0,0,0),5.0f);
			ActionManager.Instance.AddAction (tintAction, this.titleScreenSprite);
			tintAction.Run();
		}
		
		public Boolean wantNextScene()
		{
			var touches = Touch.GetData (0).ToArray();
			if((touches.Length > 0 &&
			    touches[0].Status == TouchStatus.Down) ||
			   Input2.GamePad0.Cross.Press)
			{
				return true;
			}
			return false;
		}
		
		private void fadeOutScene()
		{
			if(!this.fadingOut)
			{
				this.setAntiTintAction();
				this.fadingOut = true;
			}
			if(this.titleSongPlayer.Volume >= 0.01)
			{
				this.titleSongPlayer.Volume-=0.01f;
			}
			else
			{
				Director.Instance.ReplaceScene(new MainMenuScene());
			}
		}
	}
}

